==> yndenz-modules-navigation-2.6.7-879987.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [2.6.7] - 2018-08-23
### Fixed
- Visibility after responsive fix

## [2.6.6] - 2018-08-23
### Fixed
- Transition responsive display of search form

## [2.6.5] - 2018-08-23
### Fixed
- Responsive display search form

## [2.6.4] - 2018-08-23
### Fixed
- Toggle search display on click toggle-search class

## [2.6.3] - 2018-08-23
### Fixed
- Search form positioning

## [2.6.2] - 2018-08-23
### Fixed
- Include search form within wrapper instead of direct echo

## [2.6.1] - 2018-08-23
### Changed
- Enqueue search script when search form is included

## [2.6.0] - 2018-08-23
### Added
- Support for integrated search form

## [2.5.0] - 2018-08-16
### Changed
- Upgrade to gulp v4 and new babel preset-env

## [2.4.2] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.7...HEAD
[2.6.7]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.6...2.6.7
[2.6.6]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.5...2.6.6
[2.6.5]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.4...2.6.5
[2.6.4]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.3...2.6.4
[2.6.3]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.2...2.6.3
[2.6.2]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.1...2.6.2
[2.6.1]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.0...2.6.1
[2.6.0]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.5.0...2.6.0
[2.5.0]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.4.2...2.5.0
[2.4.2]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.4.1...2.4.2

==> yndenz-modules-navigation-3.0.0-982146.zip: changelog.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [3.0.0] - 2018-10-04
### Changed
- Code style set to WordPress standards
- Drop support for LESS
- Replace support for Boortstrap with Pure CSS

## [2.8.0] - 2018-09-17
### Changed
- Only enqueue scripts when actually required

## [2.7.1] - 2018-08-31
### Changed
- Block access to window.opener on links with target=_blank to improve security and performance

## [2.7.0] - 2018-08-30
### Added
- Context in string translation

## [2.6.7] - 2018-08-23
### Fixed
- Visibility after responsive fix

## [2.6.6] - 2018-08-23
### Fixed
- Transition responsive display of search form

## [2.6.5] - 2018-08-23
### Fixed
- Responsive display search form

## [2.6.4] - 2018-08-23
### Fixed
- Toggle search display on click toggle-search class

## [2.6.3] - 2018-08-23
### Fixed
- Search form positioning

## [2.6.2] - 2018-08-23
### Fixed
- Include search form within wrapper instead of direct echo

## [2.6.1] - 2018-08-23
### Changed
- Enqueue search script when search form is included

## [2.6.0] - 2018-08-23
### Added
- Support for integrated search form

## [2.5.0] - 2018-08-16
### Changed
- Upgrade to gulp v4 and new babel preset-env

## [2.4.2] - 2018-08-15
### Added
- Changelog file

[Unreleased]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/3.0.0...HEAD
[3.0.0]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.8.0...3.0.0
[2.8.0]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.7.1...2.8.0
[2.7.1]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.7.0...2.7.1
[2.7.0]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.7...2.7.0
[2.6.7]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.6...2.6.7
[2.6.6]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.5...2.6.6
[2.6.5]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.4...2.6.5
[2.6.4]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.3...2.6.4
[2.6.3]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.2...2.6.3
[2.6.2]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.1...2.6.2
[2.6.1]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.6.0...2.6.1
[2.6.0]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.5.0...2.6.0
[2.5.0]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.4.2...2.5.0
[2.4.2]: https://gitlab.yndenz.com/yndenz-modules/navigation/compare/2.4.1...2.4.2
